Learn R Programming

cellGrowth (version 1.16.0)

baranyi: Baranyi growth model

Description

Baranyi growth model as defined in Kelly et al.

Usage

baranyi(x, mu, l, z0, zmax)

Arguments

x
numeric vector: time points for which log(OD) must be computed
mu
numeric scalar: maximal growth rate parameter
l
numeric scalar: time lag parameter
z0
numeric scalar: minimal log(OD) parameter
zmax
numeric scalar: maximal log(OD) parameter

Value

numeric vector: log(OD) for the time points given in x

References

Kelly et al., The use of dummy data points when fitting bacterial growth curves, IMA Journal of Mathematics Applied in Medicine and Biology (1999) 16, 155-170

Examples

Run this code
x = 1:1000
y = baranyi(x, mu=0.01, l=200, z0=1, zmax=5)
plot(x,y)

Run the code above in your browser using DataLab