Learn R Programming

cellGrowth (version 1.16.0)

getWellIdsTecan: Get aliases for wells

Description

The aliases are generated by extracting the information from parsed data of the file generated by the tecan machine. See readYeastGrower and readGenios.

Usage

getWellIdsTecan(data)

Arguments

data
parsed data of the file. See readYeastGrower and readGenios

Value

vector containing the aliases

Examples

Run this code
data <- readYeastGrower( system.file("extdata", "Plate1_YPFruc.txt", package="cellGrowth"))
ids <- getWellIdsTecan(data)

Run the code above in your browser using DataLab