Learn R Programming

cellGrowth (version 1.16.0)

guessCellGrowthParams: Guess growth models parameters

Description

Guess initial parameters values for growth models

Usage

guessCellGrowthParams(x, z, relative.height.at.lag = 0.1)

Arguments

x
numeric vector: time points
z
codenumeric vector: log(OD)
relative.height.at.lag
numeric scalar (see Details)

Value

A list with entries:
mu
numeric scalar: maximal growth rate parameter
l
numeric scalar: time lag parameter
z0
numeric scalar: minimal log(OD) parameter
zmax
numeric scalar: maximal log(OD) parameter

Details

The relative.height.at.lag parameter should be close to the relative height of the point, where the curve reaches its maximal slope. If the fitting fails, try to set this parameter to a different value.

Examples

Run this code
x <- 1:1000
z <- gompertz(x, mu=0.01, l=200, z0=1, zmax=5)+rnorm(length(x),mean=0,sd=0.25)
guess <- guessCellGrowthParams(x,z,relative.height.at.lag=0.5)
fit <- nls(z~gompertz(x,mu,l,z0,zmax),start=guess)
	plot(x,z)
lines(x,predict(fit,x),lwd=2,col="red")

Run the code above in your browser using DataLab